Stan Math Library: stan/math/rev/mat/fun/log_softmax.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_softmax.hpp File Reference
`#include <stan/math/prim/arr/err/check_nonzero_size.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/log_softmax.hpp>`
`#include <stan/math/prim/mat/fun/softmax.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <cmath>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
Eigen::Matrix< var, Eigen::Dynamic, 1 > | stan::math::log_softmax (const Eigen::Matrix< var, Eigen::Dynamic, 1 > &alpha)
| Return the softmax of the specified Eigen vector. More...

## Variable Documentation

vari** alpha_

Definition at line 20 of file log_softmax.hpp.

const int idx_

Definition at line 23 of file log_softmax.hpp.

const int size_

Definition at line 22 of file log_softmax.hpp.

const double* softmax_alpha_

Definition at line 21 of file log_softmax.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.